import QtQuick 1.1

Rectangle {
    id: _root
    width: 150
    height: 40
    radius: height * 0.1    //角を丸く
    smooth: true            //なめらかに描画する
    //背景のグラデーション
    gradient: Gradient{
        GradientStop{ id: _gradBase1; position: 0.0; color: "#000000" }
        GradientStop{ id: _gradBase2; position: 0.2; color: "#444444" }
        GradientStop{ id: _gradBase3; position: 1.0; color: "#888888" }
    }
    //プロパティの定義
    property alias text: _caption.text  //--[1]
    //シグナルの定義
    signal clicked(variant mouse)       //--[2]

    //ハイライトのエリア
    Rectangle{
        anchors.fill: parent    //--[3]
        anchors.topMargin: 2
        anchors.leftMargin: 2
        anchors.rightMargin: 2
        anchors.bottomMargin: 0
        radius: parent.radius
        smooth: true
        //ハイライトのグラデーション
        gradient: Gradient{
            GradientStop{ position: 0.0; color: "#ddffffff" }
            GradientStop{ position: 0.4; color: "#44ffffff" }
            GradientStop{ position: 1.0; color: "#00ffffff" }
        }
    }
    //キャプション
    Text {
        id: _caption
        anchors.centerIn: parent    //--[4]
        color: "white"
        font.pixelSize: parent.height * 0.5     //--[5]
        text: "button"
    }
    //マウス入力
    MouseArea {     //--[6]
        id: _mouseArea
        anchors.fill: parent
        hoverEnabled: true  //マウスカーソルが重なったときの処理ON
        //左右クリックに反応（デフォルトは左のみ）
        acceptedButtons: Qt.LeftButton | Qt.RightButton
        //クリックイベント
        onClicked: {
            //シグナルを飛ばす
            _root.clicked(mouse);   //--[7]
        }
    }
    //状態管理
    states: [   //--[8]
        //マウスボタンダウン時の状態
        State{
            name: "press"
            when: _mouseArea.pressed    //マウスが押下されてるとき
            //変更するプロパティ
            PropertyChanges { target: _gradBase1; color: "#220000" }
            PropertyChanges { target: _gradBase2; color: "#440000" }
            PropertyChanges { target: _gradBase3; color: "#dd0000" }
        },
        //マウスカーソルオーバー時の状態
        State {
            name: "hover"
            when: _mouseArea.containsMouse  //カーソルが範囲内にあるとき
            //変更するプロパティ
            PropertyChanges { target: _gradBase1; color: "#000022" }
            PropertyChanges { target: _gradBase2; color: "#000044" }
            PropertyChanges { target: _gradBase3; color: "#0000dd" }
        }
    ]
}
